package Locale::CLDR::Locales::Cs::Any;

# This file auto generated
#	on Sat 24 Oct  9:26:48 am GMT

use version;

our $VERSION = version->declare('v0.28.1');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

extends('Locale::CLDR::Locales::Cs');

no Moose;
__PACKAGE__->meta->make_immutable;
